import { PublicKey, Signer } from '@metaplex-foundation/umi';
import { FreezeSolPayment, FreezeSolPaymentArgs } from '../generated';
import { GuardManifest } from '../guards';
/**
 * The freezeSolPayment guard allows minting frozen NFTs by charging
 * the payer an amount in SOL. Frozen NFTs cannot be transferred
 * or listed on any marketplaces until thawed.
 *
 * The funds are transferred to a freeze escrow until all NFTs are thaw,
 * at which point, they can be transferred (unlocked) to the configured
 * destination account.
 *
 * @see {@link FreezeSolPaymentRouteArgs} to learn more about
 * the instructions that can be executed against this guard.
 */
export declare const freezeSolPaymentGuardManifest: GuardManifest<FreezeSolPaymentArgs, FreezeSolPayment, FreezeSolPaymentMintArgs, FreezeSolPaymentRouteArgs>;
export declare type FreezeSolPaymentMintArgs = Omit<FreezeSolPaymentArgs, 'lamports'> & {};
/**
 * The settings for the freezeSolPayment guard that should be provided
 * when accessing the guard's special "route" instruction.
 */
export declare type FreezeSolPaymentRouteArgs = FreezeSolPaymentRouteArgsInitialize | FreezeSolPaymentRouteArgsThaw | FreezeSolPaymentRouteArgsUnlockFunds;
/**
 * The `initialize` path creates the freeze escrow account that will
 * hold the funds until all NFTs are thawed. It must be called before
 * any NFTs can be minted.
 *
 * ```ts
 * route(umi, {
 *   // ...
 *   guard: 'freezeSolPayment',
 *   routeArgs: {
 *     path: 'initialize',
 *     destination,
 *     period: 15 * 24 * 60 * 60, // 15 days.
 *     candyGuardAuthority,
 *   },
 * });
 * ```
 */
export declare type FreezeSolPaymentRouteArgsInitialize = Omit<FreezeSolPaymentArgs, 'lamports'> & {
    /** Selects the path to execute in the route instruction. */
    path: 'initialize';
    /** The freeze period in seconds (maximum 30 days). */
    period: number;
    /** The authority of the Candy Guard as a Signer. */
    candyGuardAuthority: Signer;
};
/**
 * The `thaw` path unfreezes one NFT if one of the following conditions are met:
 * - All NFTs have been minted.
 * - The configured period has elapsed (max 30 days).
 * - The Candy Machine account was deleted.
 *
 * Anyone can call this instruction. Since the funds are not transferrable
 * until all NFTs are thawed, it creates an incentive for the treasury to
 * thaw all NFTs as soon as possible.
 *
 * ```ts
 * route(umi, {
 *   // ...
 *   guard: 'freezeSolPayment',
 *   routeArgs: {
 *     path: 'thaw',
 *     destination,
 *     asset,
 *     collection,
 *   },
 * });
 * ```
 */
export declare type FreezeSolPaymentRouteArgsThaw = Omit<FreezeSolPaymentArgs, 'lamports'> & {
    /** Selects the path to execute in the route instruction. */
    path: 'thaw';
    /** The mint address of the NFT to thaw. */
    asset: PublicKey;
    /** The owner address of the NFT to thaw. */
    collection: PublicKey;
};
/**
 * The `unlockFunds` path transfers all of the escrow funds to the
 * configured destination address once all NFTs have been thawed.
 *
 * ```ts
 * route(umi, {
 *   // ...
 *   guard: 'freezeSolPayment',
 *   routeArgs: {
 *     path: 'unlockFunds',
 *     destination,
 *     candyGuardAuthority,
 *   },
 * });
 * ```
 */
export declare type FreezeSolPaymentRouteArgsUnlockFunds = Omit<FreezeSolPaymentArgs, 'lamports'> & {
    /** Selects the path to execute in the route instruction. */
    path: 'unlockFunds';
    /** The authority of the Candy Guard as a Signer. */
    candyGuardAuthority: Signer;
};
